colour.models.aces_rgb_idt Module — Colour 0.3.0 documentation

# colour.models.aces_rgb_idt Module

## ACES RGB Colourspace - Input Device Transform

Defines the ACES RGB colourspace Input Device Transform utilities:

- `spectral_to_aces_relative_exposure_values()`

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.oscars.org/science-technology/council/projects/aces.html (Last accessed 24 February 2014)

[2] | http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf (Last accessed 24 February 2014)

`colour.models.aces_rgb_idt.` `spectral_to_aces_relative_exposure_values`(spd, illuminant=<colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8610>)

  Converts given spectral power distribution to ACES RGB colourspace relative exposure values.

  Parameters: | spd (SpectralPowerDistribution) – Spectral power distribution. illuminant (SpectralPowerDistribution, optional) – Illuminant spectral power distribution.
  Returns: | ACES RGB colourspace relative exposure values matrix.
  Return type: | ndarray, (3,)

  Notes

  - Output ACES RGB colourspace relative exposure values matrix is in domain [0, 1].

  See also

  `colour.colorimetry.tristimulus.spectral_to_XYZ()`

  References

  Examples

      >>> from colour import COLOURCHECKERS_SPDS
      >>> spd = COLOURCHECKERS_SPDS['ColorChecker N Ohta']['dark skin']
      >>> spectral_to_aces_relative_exposure_values(spd)
      array([ 0.1187697...,  0.0870866...,  0.0589442...])